Barter-Execution
Stream private account data from financial venues, and execute (live or mock) orders. Also provides a feature rich MockExchange and MockExecutionClient to assist with backtesting and paper-trading.
It is:
- Easy: ExecutionClient trait provides a unified and simple language for interacting with exchanges.
- Normalised: Allow your strategy to communicate with every real or MockExchange using the same interface.
- Extensible: Barter-Execution is highly extensible, making it easy to contribute by adding new exchange integrations!
See README.md for more information and examples.
Re-exports
pub use fee::FeeModel;pub use fee::FeeModelConfig;pub use fee::PerContractFeeModel;pub use fee::PercentageFeeModel;pub use fee::ZeroFeeModel;pub use fill::BidAskFillModel;pub use fill::FillModel;pub use fill::LastPriceFillModel;pub use fill::MidpointFillModel;pub use fill::SimFillConfig;
Modules
- balance
- client
- Execution client implementations for various exchanges.
- error
- Error types for
ExecutionClientoperations. - exchange
- fee
- fill
- indexer
- map
- order
- position
- trade
Structs
Enums
Type Aliases
- Unindexed
Account Event - Convenient type alias for an
AccountEventkeyed withExchangeId,AssetNameExchange, andInstrumentNameExchange. - Unindexed
Account Snapshot - Convenient type alias for an
AccountSnapshotkeyed withExchangeId,AssetNameExchange, andInstrumentNameExchange.