pub fn map_sdk_error(error: Error) -> UnindexedClientErrorExpand description
Maps Hyperliquid SDK errors to UnindexedClientError.
The SDK uses its own error type internally, so we pattern-match on error messages to determine transient vs permanent errors.