pub struct HyperliquidClient { /* private fields */ }Expand description
Hyperliquid perpetual futures execution client.
Wraps the official hyperliquid_rust_sdk to implement the ExecutionClient trait.
Supports perpetual futures trading on Hyperliquid DEX.
Implementations
Sourceimpl HyperliquidClient
impl HyperliquidClient
Sourcepub async fn connect(
config: HyperliquidConfig,
) -> Result<Self, ConnectivityError>
pub async fn connect( config: HyperliquidConfig, ) -> Result<Self, ConnectivityError>
Create a new client asynchronously.
Use this when calling from an async context (e.g., tokio tests).
For sync contexts, use ExecutionClient::new().
Sourcepub fn wallet_address(&self) -> String
pub fn wallet_address(&self) -> String
Returns the wallet address as a hex string (for logging/debugging).