pub enum KeyError {
ExchangeId(String),
AssetKey(String),
InstrumentKey(String),
}Expand description
Represents errors related to exchange, asset and instrument identifier key lookups.
Variants
ExchangeId(String)
Indicates an ExchangeId was encountered that was not indexed, so does not have a
corresponding ExchangeIndex.
AssetKey(String)
Indicates an AssetNameExchange was encountered that was not indexed, so does not have a
corresponding AssetIndex.
InstrumentKey(String)
Indicates an InstrumentNameExchange was encountered that was no indexed, so does
not have a corresponding InstrumentIndex.