pub struct AccountEventIndexer {
pub map: Arc<ExecutionInstrumentMap>,
}Fields
map: Arc<ExecutionInstrumentMap>Implementations
Sourceimpl AccountEventIndexer
impl AccountEventIndexer
pub const fn new(map: Arc<ExecutionInstrumentMap>) -> AccountEventIndexer
Sourceimpl AccountEventIndexer
impl AccountEventIndexer
pub fn account_event( &self, event: UnindexedAccountEvent, ) -> Result<AccountEvent, IndexError>
pub fn snapshot( &self, snapshot: UnindexedAccountSnapshot, ) -> Result<AccountSnapshot, IndexError>
pub fn asset_balance( &self, balance: AssetBalance<AssetNameExchange>, ) -> Result<AssetBalance<AssetIndex>, IndexError>
pub fn asset_balance_update( &self, update: AssetBalanceUpdate<AssetNameExchange>, ) -> Result<AssetBalanceUpdate<AssetIndex>, IndexError>
Sourcepub fn isolated_instrument_state(
&self,
state: IsolatedInstrumentState<AssetNameExchange>,
) -> Result<IsolatedInstrumentState<AssetIndex>, IndexError>
pub fn isolated_instrument_state( &self, state: IsolatedInstrumentState<AssetNameExchange>, ) -> Result<IsolatedInstrumentState<AssetIndex>, IndexError>
Index the per-pair isolated state’s base/quote asset names to indices.
Errors
Returns IndexError if either the base or quote asset is not registered in the map —
matching the fail-fast behaviour of top-level Self::asset_balance.
Sourcepub fn instrument_balance_update(
&self,
update: InstrumentBalanceUpdate<AssetNameExchange, InstrumentNameExchange>,
) -> Result<InstrumentBalanceUpdate, IndexError>
pub fn instrument_balance_update( &self, update: InstrumentBalanceUpdate<AssetNameExchange, InstrumentNameExchange>, ) -> Result<InstrumentBalanceUpdate, IndexError>
Index an InstrumentBalanceUpdate’s instrument and base/quote asset keys.
Errors
Returns IndexError if the instrument or either asset is not registered in the map.
pub fn order_snapshot( &self, order: UnindexedOrderSnapshot, ) -> Result<OrderSnapshot, IndexError>
pub fn order_response_cancel( &self, response: OrderResponseCancel<ExchangeId, AssetNameExchange, InstrumentNameExchange>, ) -> Result<OrderResponseCancel, IndexError>
pub fn order_key(&self, key: UnindexedOrderKey) -> Result<OrderKey, IndexError>
Sourcepub fn order_state(
&self,
state: UnindexedOrderState,
) -> Result<OrderState, IndexError>
pub fn order_state( &self, state: UnindexedOrderState, ) -> Result<OrderState, IndexError>
Index an UnindexedOrderState to an OrderState.
Used by ExecutionManager to index open_order responses.
pub fn api_error( &self, error: UnindexedApiError, ) -> Result<ApiError, IndexError>
pub fn order_request<Kind>(
&self,
order: &OrderEvent<Kind, ExchangeIndex, InstrumentIndex>,
) -> Result<OrderEvent<Kind, ExchangeId, &InstrumentNameExchange>, KeyError>where
Kind: Clone,
pub fn order_error( &self, error: UnindexedOrderError, ) -> Result<OrderError, IndexError>
pub fn client_error( &self, error: UnindexedClientError, ) -> Result<ClientError, IndexError>
Sourcepub fn trade(
&self,
trade: Trade<AssetNameExchange, InstrumentNameExchange>,
) -> Result<Trade<AssetIndex, InstrumentIndex>, IndexError>
pub fn trade( &self, trade: Trade<AssetNameExchange, InstrumentNameExchange>, ) -> Result<Trade<AssetIndex, InstrumentIndex>, IndexError>
Index a trade, converting fee asset and computing fees_quote.
Computes fees_quote based on fee asset relationship to instrument:
- Fee in quote asset:
fees_quote = Some(fees) - Fee in base asset:
fees_quote = Some(fees * price) - Fee in third-party asset (e.g., BNB):
fees_quote = None
Errors
Returns IndexError if fee asset is not in the map. Some integrations use
“UNKNOWN” as a placeholder when fee data is unavailable (e.g., IBKR fetch_trades,
Binance when API omits commission_asset). These trades will fail indexing.