Module order

Module order 

Modules

bracket
Bracket order types for the BracketOrderClient trait. Bracket order types for the BracketOrderClient trait.
id
Order related identifiers.
request
Order open and cancel request types.
state
Order states.

Structs

Order
OrderEvent
OrderKey

Enums

OrderKind
TimeInForce
TrailingOffsetType
Specifies how the trailing offset is measured for trailing stop orders.

Type Aliases

OrderSnapshot
Convenient type alias for an Order OrderState snapshot.
UnindexedOrder
Convenient type alias for an Order keyed with ExchangeId and InstrumentNameExchange.
UnindexedOrderKey
Convenient type alias for an OrderKey keyed with ExchangeId and InstrumentNameExchange.
UnindexedOrderSnapshot
Convenient type alias for an OrderSnapshot keyed with ExchangeId, AssetNameExchange, and InstrumentNameExchange.