#[non_exhaustive]pub enum OrderKind {
Market,
Limit,
Stop {
trigger_price: Decimal,
},
StopLimit {
trigger_price: Decimal,
},
TakeProfit {
trigger_price: Decimal,
},
TakeProfitLimit {
trigger_price: Decimal,
},
TrailingStop {
offset: Decimal,
offset_type: TrailingOffsetType,
},
TrailingStopLimit {
offset: Decimal,
offset_type: TrailingOffsetType,
limit_offset: Decimal,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Market
Limit
Stop
Stop (market) order - triggers a market order when trigger_price is reached.
StopLimit
Stop-limit order - triggers a limit order at Order.price when trigger_price is reached.
TakeProfit
Take-profit (market) order - triggers a market order when trigger_price is reached. Opposite of Stop: triggers when price moves favorably (above for longs, below for shorts).
TakeProfitLimit
Take-profit limit order - triggers a limit order at Order.price when trigger_price is reached.
TrailingStop
Trailing stop order - stop price trails the market by a specified offset.
TrailingStopLimit
Trailing stop-limit order - when triggered, submits a limit order offset from the stop.