pub enum OrderKind {
Market,
Limit,
Stop {
trigger_price: Decimal,
},
StopLimit {
trigger_price: Decimal,
},
TrailingStop {
offset: Decimal,
offset_type: TrailingOffsetType,
},
TrailingStopLimit {
offset: Decimal,
offset_type: TrailingOffsetType,
limit_offset: Decimal,
},
}Variants
Market
Limit
Stop
Stop (market) order - triggers a market order when trigger_price is reached.
StopLimit
Stop-limit order - triggers a limit order at Order.price when trigger_price is reached.
TrailingStop
Trailing stop order - stop price trails the market by a specified offset.
TrailingStopLimit
Trailing stop-limit order - when triggered, submits a limit order offset from the stop.